@@ -1,11 +1,12 @@
 __authors__ = ['Thorin Tabor', 'Chet Birger']
 __copyright__ = 'Copyright 2015-2016, Broad Institute'
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 __status__ = 'Production'
 
-""" GenePattern Python Client
+"""
+GenePattern Python Client
 
-    Compatible with Python 2.7 and Python 3.4
+Compatible with Python 2.7 and Python 3.4+
 """
 
 
